@@ -42,6 +42,8 @@
 #include <klocale.h>
 #include <kstandarddirs.h>
 
+#include <Solid/PowerManagement>
+
 #include <QtCore/QDir>
 #include <QtCore/QSettings>
 #include <QtCore/QTimer>
@@ -259,6 +261,8 @@ void AgentBasePrivate::init()
   connect( q, SIGNAL( warning( const QString& ) ), q, SLOT( slotWarning( const QString& ) ) );
   connect( q, SIGNAL( error( const QString& ) ), q, SLOT( slotError( const QString& ) ) );
 
+  connect( Solid::PowerManagement::notifier(), SIGNAL(resumingFromSuspend()), q, SLOT(slotResumedFromSuspend()) );
+
   // Use reference counting to allow agents to finish internal jobs when the
   // agent is stopped.
   KGlobal::ref();
@@ -492,6 +496,12 @@ void AgentBasePrivate::slotNetworkStatusChange( Solid::Networking::Status stat )
   q->setOnline( stat == Solid::Networking::Unknown || stat == Solid::Networking::Connected );
 }
 
+void AgentBasePrivate::slotResumedFromSuspend()
+{
+  if ( mNeedsNetwork )
+    slotNetworkStatusChange( Solid::Networking::status() );
+}
+
 AgentBase::AgentBase( const QString & id )
   : d_ptr( new AgentBasePrivate( this ) )
 {
