@@ -26,7 +26,7 @@
 using namespace Akonadi;
 
 ChangeRecorder::ChangeRecorder( QObject * parent ) :
-    Monitor( new ChangeRecorderPrivate( this ), parent )
+    Monitor( new ChangeRecorderPrivate( 0, this ), parent )
 {
 }
 
@@ -35,7 +35,7 @@ ChangeRecorder::ChangeRecorder( ChangeRecorderPrivate *privateclass, QObject * p
 {
 }
 
-ChangeRecorder::~ ChangeRecorder()
+ChangeRecorder::~ChangeRecorder()
 {
   Q_D( ChangeRecorder );
   d->saveNotifications();
@@ -58,11 +58,15 @@ void ChangeRecorder::replayNext()
 {
   Q_D( ChangeRecorder );
   if ( !d->pendingNotifications.isEmpty() ) {
-    const NotificationMessage msg = d->pendingNotifications.first();
+    const NotificationMessage msg = d->pendingNotifications.head();
     if ( d->ensureDataAvailable( msg ) )
       d->emitNotification( msg );
-    else
-      d->pipeline.enqueue( msg );
+    else if ( !d->translateAndCompress( d->pipeline, msg ) ) {
+      // In the case of a move where both source and destination are
+      // ignored, we ignore the message and process the next one.
+      d->pendingNotifications.dequeue();
+      return replayNext();
+    }
   } else {
     // This is necessary when none of the notifications were accepted / processed
     // above, and so there is no one to call changeProcessed() and the ChangeReplay task
@@ -82,7 +86,7 @@ void ChangeRecorder::changeProcessed()
 {
   Q_D( ChangeRecorder );
   if ( !d->pendingNotifications.isEmpty() )
-    d->pendingNotifications.removeFirst();
+    d->pendingNotifications.dequeue();
   d->saveNotifications();
 }
 
