@@ -20,8 +20,10 @@
 */
 
 #include "collectioncombobox.h"
+#include "collectioncombobox_p.h"
 
 #include "asyncselectionhandler_p.h"
+#include "collectiondialog.h"
 
 #include <akonadi/changerecorder.h>
 #include <akonadi/collectionfetchscope.h>
@@ -30,10 +32,12 @@
 #include <akonadi/entitytreemodel.h>
 #include <akonadi/session.h>
 
-#include "kdescendantsproxymodel_p.h"
+#include <kdescendantsproxymodel.h>
 #include "collectionutils_p.h"
 
 #include <QtCore/QAbstractItemModel>
+#include <QtCore/QEvent>
+#include <QtGui/QMouseEvent>
 
 using namespace Akonadi;
 
@@ -43,10 +47,8 @@ class CollectionComboBox::Private
     Private( QAbstractItemModel *customModel, CollectionComboBox *parent )
       : mParent( parent ), mMonitor( 0 ), mModel( 0 )
     {
-      QAbstractItemModel *baseModel;
-
       if ( customModel ) {
-        baseModel = customModel;
+        mBaseModel = customModel;
       } else {
         mMonitor = new Akonadi::ChangeRecorder( mParent );
         mMonitor->fetchCollection( true );
@@ -55,12 +57,12 @@ class CollectionComboBox::Private
         mModel = new EntityTreeModel( mMonitor, mParent );
         mModel->setItemPopulationStrategy( EntityTreeModel::NoItemPopulation );
 
-        baseModel = mModel;
+        mBaseModel = mModel;
       }
 
       KDescendantsProxyModel *proxyModel = new KDescendantsProxyModel( parent );
       proxyModel->setDisplayAncestorData( true );
-      proxyModel->setSourceModel( baseModel );
+      proxyModel->setSourceModel( mBaseModel );
 
       mMimeTypeFilterModel = new CollectionFilterProxyModel( parent );
       mMimeTypeFilterModel->setSourceModel( proxyModel );
@@ -89,6 +91,7 @@ class CollectionComboBox::Private
 
     ChangeRecorder *mMonitor;
     EntityTreeModel *mModel;
+    QAbstractItemModel *mBaseModel;
     CollectionFilterProxyModel *mMimeTypeFilterModel;
     EntityRightsFilterModel *mRightsFilterModel;
     AsyncSelectionHandler *mSelectionHandler;
@@ -106,15 +109,63 @@ void CollectionComboBox::Private::activated( const QModelIndex &index )
   mParent->setCurrentIndex( index.row() );
 }
 
+MobileEventHandler::MobileEventHandler( CollectionComboBox *comboBox, CollectionFilterProxyModel *mimeTypeFilter,
+                                        EntityRightsFilterModel *accessRightsFilter, QAbstractItemModel *customModel )
+  : QObject( comboBox ),
+    mComboBox( comboBox ),
+    mMimeTypeFilter( mimeTypeFilter ),
+    mAccessRightsFilter( accessRightsFilter ),
+    mCustomModel( customModel )
+{
+}
+
+bool MobileEventHandler::eventFilter( QObject *object, QEvent *event )
+{
+  if ( object == mComboBox && mComboBox->isEnabled() && event->type() == QEvent::MouseButtonPress ) {
+
+    const QMouseEvent *mouseEvent = static_cast<QMouseEvent*>( event );
+
+    // we receive mouse events from other widgets as well, so check for ours
+    if ( mComboBox->rect().contains( mouseEvent->pos() ) ) {
+      QMetaObject::invokeMethod( this, "openDialog", Qt::QueuedConnection );
+    }
+
+    return true;
+  }
+
+  return QObject::eventFilter( object, event );
+}
+
+void MobileEventHandler::openDialog()
+{
+  Akonadi::CollectionDialog dialog( mCustomModel );
+  dialog.setMimeTypeFilter( mMimeTypeFilter->mimeTypeFilters() );
+  dialog.setAccessRightsFilter( mAccessRightsFilter->accessRights() );
+
+  if ( dialog.exec() ) {
+    const Akonadi::Collection collection = dialog.selectedCollection();
+    const QModelIndex index = Akonadi::EntityTreeModel::modelIndexForCollection( mComboBox->model(), collection );
+    mComboBox->setCurrentIndex( index.row() );
+  }
+}
+
 
 CollectionComboBox::CollectionComboBox( QWidget *parent )
   : KComboBox( parent ), d( new Private( 0, this ) )
 {
+#ifdef KDEPIM_MOBILE_UI
+  MobileEventHandler *handler = new MobileEventHandler( this, d->mMimeTypeFilterModel, d->mRightsFilterModel, d->mBaseModel );
+  installEventFilter( handler );
+#endif
 }
 
 CollectionComboBox::CollectionComboBox( QAbstractItemModel *model, QWidget *parent )
   : KComboBox( parent ), d( new Private( model, this ) )
 {
+#ifdef KDEPIM_MOBILE_UI
+  MobileEventHandler *handler = new MobileEventHandler( this, d->mMimeTypeFilterModel, d->mRightsFilterModel, d->mBaseModel );
+  installEventFilter( handler );
+#endif
 }
 
 CollectionComboBox::~CollectionComboBox()
@@ -162,3 +213,4 @@ Akonadi::Collection CollectionComboBox::currentCollection() const
 }
 
 #include "collectioncombobox.moc"
+#include "collectioncombobox_p.moc"
