@@ -26,6 +26,7 @@
 #include "collectionsync_p.h"
 #include "dbusconnectionpool.h"
 #include "itemsync.h"
+#include "kdepimlibs-version.h"
 #include "resourcescheduler_p.h"
 #include "tracerinterface.h"
 #include "xdgbasedirs_p.h"
@@ -72,7 +73,8 @@ class Akonadi::ResourceBasePrivate : public AgentBasePrivate
         mItemTransactionMode( ItemSync::SingleTransaction ),
         mCollectionSyncer( 0 ),
         mHierarchicalRid( false ),
-        mUnemittedProgress( 0 )
+        mUnemittedProgress( 0 ),
+        mAutomaticProgressReporting( true )
     {
       Internal::setClientType( Internal::Resource );
       mStatusMessage = defaultReadyMessage();
@@ -273,6 +275,7 @@ class Akonadi::ResourceBasePrivate : public AgentBasePrivate
     QTimer mProgressEmissionCompressor;
     int mUnemittedProgress;
     QMap<Akonadi::Collection::Id, QVariantMap> mUnemittedAdvancedStatus;
+    bool mAutomaticProgressReporting;
 };
 
 ResourceBase::ResourceBase( const QString & id )
@@ -372,7 +375,7 @@ QString ResourceBase::parseArguments( int argc, char **argv )
   const QByteArray catalog = fi.baseName().toLatin1();
 
   KCmdLineArgs::init( argc, argv, identifier.toLatin1(), catalog,
-                      ki18nc( "@title application name", "Akonadi Resource" ), "0.1",
+                      ki18nc( "@title application name", "Akonadi Resource" ), KDEPIMLIBS_VERSION,
                       ki18nc( "@title application description", "Akonadi Resource" ) );
 
   KCmdLineOptions options;
@@ -656,7 +659,9 @@ void ResourceBasePrivate::slotSynchronizeCollection( const Collection &col )
   QStringList contentTypes = currentCollection.contentMimeTypes();
   contentTypes.removeAll( Collection::mimeType() );
   if ( !contentTypes.isEmpty() || (col.rights() & (Collection::CanLinkItem)) ) { // HACK to check for virtual collections
-    emit q->status( AgentBase::Running, i18nc( "@info:status", "Syncing collection '%1'", currentCollection.name() ) );
+    if ( mAutomaticProgressReporting ) {
+      emit q->status( AgentBase::Running, i18nc( "@info:status", "Syncing collection '%1'", currentCollection.name() ) );
+    }
     q->retrieveItems( currentCollection );
     return;
   }
@@ -887,10 +892,12 @@ void ResourceBasePrivate::slotItemSyncDone( KJob *job )
 void ResourceBasePrivate::slotDelayedEmitProgress()
 {
   Q_Q( ResourceBase );
-  emit q->percent( mUnemittedProgress );
+  if ( mAutomaticProgressReporting ) {
+    emit q->percent( mUnemittedProgress );
 
-  Q_FOREACH( const QVariantMap &statusMap, mUnemittedAdvancedStatus ) {
-      emit q->advancedStatus( statusMap );
+    Q_FOREACH( const QVariantMap &statusMap, mUnemittedAdvancedStatus ) {
+        emit q->advancedStatus( statusMap );
+    }
   }
   mUnemittedProgress = 0;
   mUnemittedAdvancedStatus.clear();
@@ -898,8 +905,6 @@ void ResourceBasePrivate::slotDelayedEmitProgress()
 
 void ResourceBasePrivate::slotPercent( KJob *job, unsigned long percent )
 {
-  Q_Q( ResourceBase );
-
   mUnemittedProgress = percent;
 
   const Collection collection = job->property( "collection" ).value<Collection>();
@@ -962,5 +967,11 @@ void ResourceBase::setItemSynchronizationFetchScope(const ItemFetchScope& fetchS
   *(d->mItemSyncFetchScope) = fetchScope;
 }
 
+void ResourceBase::setAutomaticProgressReporting( bool enabled )
+{
+  Q_D( ResourceBase );
+  d->mAutomaticProgressReporting = enabled;
+}
+
 #include "resourcebase.moc"
 #include "moc_resourcebase.cpp"
