@@ -21,7 +21,6 @@
 #include "emailquotehighlighter.h"
 
 #include "textedit.h"
-#include <kdeversion.h>
 
 namespace KPIMTextEdit {
 
@@ -142,11 +141,7 @@ void EMailQuoteHighlighter::highlightBlock( const QString & text )
     }
     else
     {
-        if ( d->spellCheckingEnabled 
-#if KDE_IS_VERSION(4,4,93)
-			&& checkerEnabledByDefault()
-#endif
-			)
+        if ( d->spellCheckingEnabled && checkerEnabledByDefault() )
             Highlighter::highlightBlock( text );
     }
     setCurrentBlockState( 0 );
