@@ -34,6 +34,9 @@ class TextEditTester : public QObject
     void testEnter_data();
     void testImages();
     void testImageHtmlCode();
+    void testDeleteLine();
+    void testDeleteLine_data();
+    void testLoadImage();
 };
 
 #endif
